package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.AnnualInspectionDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.AnnualInspectionDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.AnnualInspectionDataRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class AnnualInspectionDataService {

    @Resource
    private AnnualInspectionDataMapper annualInspectionDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 终止时间
     * @return
     * @description 将年检数据放入redis中
     * @date 2020/2/4 11:52 上午
     */
    public void putAnnualInspectionDataToRedis(CommonRequest commonRequest) {
        List<AnnualInspectionDataModel> annualInspectionDataModelList =
                annualInspectionDataMapper.getAnnualInspectionDataList(commonRequest);
        //将数据放入redis中
        redisTemplate.opsForValue().set(DataStatisticsConstants.ANNUAL_INSPECTION_DATA_FIELD, annualInspectionDataModelList);
    }

    /**
     * @param annualInspectionDataRequest
     * @return
     * @description 从redis中获取年检信息
     * @date 2020/2/4 1:18 下午
     */
    public List<AnnualInspectionDataModel> getAnnualInspectionDataListFromRedis(
            AnnualInspectionDataRequest annualInspectionDataRequest) {
        List<AnnualInspectionDataModel> annualInspectionDataModelList = (List<AnnualInspectionDataModel>)
                redisTemplate.opsForValue().get(DataStatisticsConstants.ANNUAL_INSPECTION_DATA_FIELD);
        if(annualInspectionDataModelList != null && annualInspectionDataModelList.size() > 0){
            annualInspectionDataModelList = annualInspectionDataModelList.stream()
                    .filter(a -> a.getMtCompanyId().equals(annualInspectionDataRequest.getMtCompanyId()))
                    .collect(Collectors.toList());
        }
        return annualInspectionDataModelList;
    }

}
