package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.ContractDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.ContractDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.ContractDataRequest;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class ContractDataService {

    @Resource
    private ContractDataMapper contractDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 结束时间
     * @return
     * @description 将合同数据放入redis中
     * @date 2020/2/4 11:17 上午
     */
    public void putContractDataToRedis(CommonRequest commonRequest) {
        List<ContractDataModel> contractDataModelList = contractDataMapper.getContractDataList(commonRequest);
        //将合同数据放入redis中
        redisTemplate.opsForValue().set(DataStatisticsConstants.CONTRACT_DATA_FIELD, contractDataModelList);
    }

    /**
     * @param contractDataRequest 起始时间 终止时间
     * @return
     * @description 获取合同数据
     * @date 2020/2/4 11:47 上午
     */
    public List<ContractDataModel> getContractDataListFromRedis(ContractDataRequest contractDataRequest) {
        List<ContractDataModel> contractDataModelList = (List<ContractDataModel>) redisTemplate.opsForValue()
                .get(DataStatisticsConstants.CONTRACT_DATA_FIELD);
        if (contractDataModelList != null && contractDataModelList.size() > 0) {
            //通过公司id过滤合同数据
            contractDataModelList = contractDataModelList.stream()
                    .filter(a -> a.getMtCompanyId().equals(contractDataRequest.getMtCompanyId()))
                    .collect(Collectors.toList());
        }
        return contractDataModelList;
    }

}
