package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.EmergencyRepairDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.EmergencyRepairDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.EmergencyRepairDataRequest;
import cn.com.ty.lift.batch.applet.util.DataStatisticsUtil;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class EmergencyRepairDataService {

    @Resource
    private EmergencyRepairDataMapper emergencyRepairDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间，结束时间
     * @return
     * @description 将指定的急修数据放入redis中
     * @date 2020/2/3 3:33 下午
     */
    public void putEmergencyRepairDataListToRedis(CommonRequest commonRequest) {
        //获取时间段内的急修数据
        List<EmergencyRepairDataModel> emergencyRepairDataModelList = emergencyRepairDataMapper
                .getEmergencyRepairDataList(commonRequest);
        //通过公司id给数据分组
        Map<Long, List<EmergencyRepairDataModel>> mtCompanyIdToEmergencyRepair = emergencyRepairDataModelList.stream()
                .collect(Collectors.groupingBy(EmergencyRepairDataModel::getMtCompanyId));
        //将急修时间段内的数据放入redis缓存中
        redisTemplate.opsForValue().set(DataStatisticsConstants.EMERGENCY_REPAIR_DATA_FIELD, mtCompanyIdToEmergencyRepair);
    }

    /**
     * @param emergencyRepairDataRequest 起始时间，结束时间
     * @return
     * @description 获取年度急修数据
     * @date 2020/2/3 4:28 下午
     */
    public List<EmergencyRepairDataModel> getEmergencyRepairDataListFromRedis(EmergencyRepairDataRequest
                                                                                      emergencyRepairDataRequest) {
        Map<Long, List<EmergencyRepairDataModel>> mtCompanyIdToEmergencyRepair = (Map<Long, List<EmergencyRepairDataModel>>)
                redisTemplate.opsForValue().get(DataStatisticsConstants.EMERGENCY_REPAIR_DATA_FIELD);
        List<EmergencyRepairDataModel> emergencyRepairDataModelList = mtCompanyIdToEmergencyRepair
                .get(emergencyRepairDataRequest.getMtCompanyId());
        if (emergencyRepairDataModelList != null && emergencyRepairDataModelList.size() > 0) {
            //过滤起始时间之前的数据
            if (emergencyRepairDataRequest.getStartTimeDate() != null) {
                emergencyRepairDataModelList = emergencyRepairDataModelList.stream()
                        .filter(a -> a.getCallerDate().isAfter(emergencyRepairDataRequest.getStartTimeDate()))
                        .collect(Collectors.toList());
            }
            //过滤终止时间之后的数据
            if (emergencyRepairDataRequest.getEndTimeDate() != null) {
                emergencyRepairDataModelList = emergencyRepairDataModelList.stream()
                        .filter(a -> a.getCallerDate().isBefore(emergencyRepairDataRequest.getEndTimeDate()))
                        .collect(Collectors.toList());
            }
        }
        return emergencyRepairDataModelList;
    }

    /**
     * @param
     * @return
     * @description 以月为维度统计每个月急修的电梯台量
     * @date 2020/2/4 3:04 下午
     */
    public RestResponse getEachMonthUnits(EmergencyRepairDataRequest emergencyRepairDataRequest) {
        Map<String, Long> monthToUnits = DataStatisticsUtil.initDateMap();
        emergencyRepairDataRequest.setStartTimeDate(DataStatisticsUtil.getYearFirstTime());
        emergencyRepairDataRequest.setEndTimeDate(LocalDateTime.now());
        //从redis中获取时间段内的急修数据
        List<EmergencyRepairDataModel> emergencyRepairDataModelList =
                getEmergencyRepairDataListFromRedis(emergencyRepairDataRequest);
        //将数据组合成月->台量的map
        Map<String, Long> monthToUnitsRow = emergencyRepairDataModelList.stream()
                .collect(Collectors.groupingBy(emergencyRepairDataModel ->
                        DataStatisticsUtil.getMonthStr(emergencyRepairDataModel.getCallerDate()), Collectors.counting()));
        //将monthToUnitsRow月份对应台量的值放入monthToUnits中
        monthToUnitsRow.forEach((key, value) -> monthToUnits.put(key, value));
        return RestResponse.success(monthToUnits, ApiConstants.RESULT_SUCCESS, "获取统计数据成功");
    }
}
