package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.LiftDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.LiftDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.LiftDataRequest;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class LiftDataService {

    @Resource
    private LiftDataMapper liftDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 终止时间
     * @return
     * @description 将电梯数据放入redis中
     * @date 2020/2/4 10:24 上午
     */
    public void putLiftDataListToRedis(CommonRequest commonRequest) {
        List<LiftDataModel> liftDataModelList = liftDataMapper.getLiftDataList(commonRequest);
        //将电梯数据放入redis中
        redisTemplate.opsForValue().set(DataStatisticsConstants.LIFT_DATA_FIELD, liftDataModelList);
    }

    /**
     * @param liftDataRequest 起始时间 终止时间
     * @return
     * @description
     * @date 2020/2/4 10:36 上午
     */
    public List<LiftDataModel> getLiftDataListFromRedis(LiftDataRequest liftDataRequest) {
        List<LiftDataModel> liftDataModelList = (List<LiftDataModel>) redisTemplate.opsForValue()
                .get(DataStatisticsConstants.LIFT_DATA_FIELD);
        //通过公司id过滤电梯数据
        liftDataModelList = liftDataModelList.stream()
                .filter(a -> a.getMtCompanyId().equals(liftDataRequest.getMtCompanyId()))
                .collect(Collectors.toList());
        //过滤起始时间之前的数据
        if(liftDataRequest.getStartTimeDate() != null){
            liftDataModelList = liftDataModelList.stream()
                    .filter(a -> a.getConnectTime().isAfter(liftDataRequest.getStartTimeDate()))
                    .collect(Collectors.toList());
        }
        //过滤终止时间之后的数据
        if(liftDataRequest.getEndTimeDate() != null){
            liftDataModelList = liftDataModelList.stream()
                    .filter(a -> a.getConnectTime().isBefore(liftDataRequest.getEndTimeDate()))
                    .collect(Collectors.toList());
        }
        return liftDataModelList;
    }

}
