package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.MaintenanceDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.MaintenanceDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.MaintenanceDataRequest;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class MaintenanceDataService {

    @Resource
    private MaintenanceDataMapper maintenanceDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 终止时间
     * @return
     * @description 将维保数据放入redis中
     * @date 2020/2/4 1:50 下午
     */
    public void putMaintenanceDataListToRedis(CommonRequest commonRequest) {
        List<MaintenanceDataModel> maintenanceDataModelList = maintenanceDataMapper.getMaintenanceDataList(commonRequest);
        //将维保数据放入redis中
        redisTemplate.opsForValue().set(DataStatisticsConstants.EMERGENCY_REPAIR_DATA_FIELD, maintenanceDataModelList);
    }

    /**
     * @param
     * @return
     * @description 将维保数据从redis中取出来
     * @date 2020/2/4 2:04 下午
     */
    public List<MaintenanceDataModel> getMaintenanceDataListFromRedis(MaintenanceDataRequest maintenanceDataRequest) {
        List<MaintenanceDataModel> maintenanceDataModelList = (List<MaintenanceDataModel>)
                redisTemplate.opsForValue().get(DataStatisticsConstants.MAINTENANCE_DATA_FIELD);
        if(maintenanceDataModelList != null && maintenanceDataModelList.size() > 0){
            //通过公司id过滤维保数据
            maintenanceDataModelList = maintenanceDataModelList.stream()
                    .filter(a -> a.getMtCompanyId().equals(maintenanceDataRequest.getMtCompanyId()))
                    .collect(Collectors.toList());
        }
        return maintenanceDataModelList;
    }

}
