package cn.com.ty.lift.batch.applet.service;

import cn.com.ty.lift.batch.applet.constants.DataStatisticsConstants;
import cn.com.ty.lift.batch.applet.dao.mapper.PaymentDataMapper;
import cn.com.ty.lift.batch.applet.dao.model.PaymentDataModel;
import cn.com.ty.lift.batch.applet.dao.model.request.CommonRequest;
import cn.com.ty.lift.batch.applet.dao.model.request.PaymentDataRequest;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author huangyuan
 * @date 2020/2/3
 * @description
 */
@Service
public class PaymentDataService {

    @Resource
    private PaymentDataMapper paymentDataMapper;

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @param commonRequest 起始时间 结束时间
     * @return
     * @description 将收款数据放入redis中
     * @date 2020/2/4 2:20 下午
     */
    public void putPaymentDataToRedis(CommonRequest commonRequest) {
        List<PaymentDataModel> paymentDataModelList = paymentDataMapper.getPaymentDataList(commonRequest);
        //将收款数据放入redis中
        redisTemplate.opsForValue().set(DataStatisticsConstants.PAYMENT_DATA_FIELD, paymentDataModelList);
    }

    /**
     * @param paymentDataRequest
     * @return
     * @description 从redis中获取收款数据
     * @date 2020/2/4 2:30 下午
     */
    public List<PaymentDataModel> getPaymentDataListFromRedis(PaymentDataRequest paymentDataRequest) {
        List<PaymentDataModel> paymentDataModelList = (List<PaymentDataModel>)
                redisTemplate.opsForValue().get(DataStatisticsConstants.PAYMENT_DATA_FIELD);
        if(paymentDataModelList != null && paymentDataModelList.size() > 0){
            //通过公司id过滤
            paymentDataModelList = paymentDataModelList.stream()
                    .filter(a -> a.getMtCompanyId().equals(paymentDataRequest.getMtCompanyId()))
                    .collect(Collectors.toList());
        }
        return paymentDataModelList;
    }

}
